@@ -117,6 +117,7 @@ def make_arg_kwargs(arg_def):
 
     nargs = get_document_property(arg_def, "nargs")
     action = get_document_property(arg_def, "action")
+    value_type = get_document_property(arg_def, "valueType")
 
     if nargs is not None:
         if nargs == 0:
@@ -127,6 +128,9 @@ def make_arg_kwargs(arg_def):
     if action is not None:
         kwargs["action"] = action
 
+    if value_type is not None:
+        kwargs["type"] = value_type
+
     default = get_document_property(arg_def, "default")
 
     kwargs["default"] = default
@@ -485,4 +489,4 @@ def resolve_function(full_func_name):
     for name in names[1:]:
         result = getattr(result, name)
 
-    return result
\ No newline at end of file
+    return result
